ident

Function ident 

pub fn ident<'src>() -> impl Parser<'src, &'src str, String, Err<Simple<'src, char>>> + Clone
Parse the text of an unquoted SST identifier without wrapping it in Ident.

Dots and colons are accepted for hardware and namespaced identifiers. The @ sigil, quotes, pattern metacharacters, whitespace, and structural delimiters are rejected.